==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S14c35992b3eeb3593c43cfae3371bd50.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "S749d2b576e15d77f0d14f186077e9ace.h"
 class Se812b5a98988bad1d5b8df118cb6cc7f; class S61b72eb6355a70814ce18eb4f7efa68a { Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179; bool Sb7fe9de2263da74bb3cfa87302514f81; public: unsigned long *S1873719b7bdf1d0bee02a590a8697cee; 
unsigned long Seae5ce4a46f8588301cf393fc3cdb6ce; long S198a6617dc07f3411d5c2ab23837bf26; unsigned long 
Sdebc544362bc88fbc79869c3454e638e; bool *Sf08fc651063a116b713c21fe0483d8e6; bool *S97237417ba96257dcca522646834e728; 
bool *Sf4fc158ddab359ab818e5fe86c1d181a; bool Sfedb2d84cafe20862cb4399751a8a7e3; S749d2b576e15d77f0d14f186077e9ace 
S9c28d32df234037773be184dbdafc274; S749d2b576e15d77f0d14f186077e9ace S2f0056df010e0231e4cca0e382df44fc; 
public: bool Se4d23e841d8e8804190027bce3180fa5; S61b72eb6355a70814ce18eb4f7efa68a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, unsigned long Sa1e1f9c9bdfe7685923fdcc864bb786d, unsigned long S334186d69ff0c3752a510764ff3936fb); 
S61b72eb6355a70814ce18eb4f7efa68a(Se812b5a98988bad1d5b8df118cb6cc7f &S8c9a70dc1e604715e475d87430ba602d, 
unsigned long Sa1e1f9c9bdfe7685923fdcc864bb786d, const char *S7b0bb31f74b768daebbb6fb1a58041d9); S61b72eb6355a70814ce18eb4f7efa68a(const 
S61b72eb6355a70814ce18eb4f7efa68a &S86f8ed871a2e326f1154816761110c14); S61b72eb6355a70814ce18eb4f7efa68a(const 
S61b72eb6355a70814ce18eb4f7efa68a *S86f8ed871a2e326f1154816761110c14); ~S61b72eb6355a70814ce18eb4f7efa68a(void); 
S749d2b576e15d77f0d14f186077e9ace S77c92c7ddc071b07c527c9aa316f9328(void); S749d2b576e15d77f0d14f186077e9ace 
S3847bcc45274dd7c7e58efde3c5bef5a(void); S749d2b576e15d77f0d14f186077e9ace S73adfbe2da28341c45025580f412dc2a(void); 
S749d2b576e15d77f0d14f186077e9ace S2039596f6ccbcda87d5cea9313eb875c(void); bool S86630e1219027176737806157efbaf85(bool 
S573dda16c70458ee6b07a928cb142ddd) const; unsigned long Se4b88616283e7b4ddbb47516cb65dd36(void); void 
Sb124f23641d6f0fbf485d960ab72f437(unsigned long Sd95f9e04ad300554e3b6d2a4adfce1d2); unsigned long S993245c02a3c79568cb78880cd19a354(void); 
bool S02c10b49404aaec2099505999fe25cc5(void); bool Sf5153c63562142755896713a10b182d8(S61b72eb6355a70814ce18eb4f7efa68a 
&S059e8e571ae4fde1edb06763ac8d24f3); unsigned long S6e8c99bdce2bf9e14b6551fe3fd8cfe4(void); unsigned 
long S0cc61c6ca9d6e8d9782916904cc7f3c3(void); unsigned long Sde05f11e7794a28277eebf072900317c(void); 
unsigned long S0a0d318df5c053ae7319b1ec49b6e5e8(unsigned long Sc9e9a848920877e76685b2e4e76de38d = 0); 
unsigned long S2c8387b06995b10ae9a20fd58f79f49b(unsigned long Sc9e9a848920877e76685b2e4e76de38d = 0); 
unsigned long Sa90ec4ae976bb784cdc7b0bb80b48e1e(void);  bool *Se9ef9363cbe9a5f39a8cb510a2e042f0(void); 
void S97f1e170874a22f3776249625ec3d7b8( void *S0c9e7da67cf114aa81ef570bf9b35e6b); bool operator ==(const 
S61b72eb6355a70814ce18eb4f7efa68a &S86f8ed871a2e326f1154816761110c14); bool operator !=(const S61b72eb6355a70814ce18eb4f7efa68a 
&S86f8ed871a2e326f1154816761110c14); void S13dba24862cf9128167a59100e154c8d(S1356d0666866080ee569a8007f7465e0 
&Sd95679752134a2d9eb61dbd7b91c4bcc) const; };  typedef S61b72eb6355a70814ce18eb4f7efa68a *Sd8841b74cc206cdcb1580e1d6a9f3071; 
S1356d0666866080ee569a8007f7465e0 &operator << (S1356d0666866080ee569a8007f7465e0 &Sd95679752134a2d9eb61dbd7b91c4bcc, 
const S61b72eb6355a70814ce18eb4f7efa68a &S86f8ed871a2e326f1154816761110c14);

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S14c35992b3eeb3593c43cfae3371bd50.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "S749d2b576e15d77f0d14f186077e9ace.h"
 class Se812b5a98988bad1d5b8df118cb6cc7f; class S61b72eb6355a70814ce18eb4f7efa68a { Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179; bool Sb7fe9de2263da74bb3cfa87302514f81; public: unsigned long *S1873719b7bdf1d0bee02a590a8697cee; 
unsigned long Seae5ce4a46f8588301cf393fc3cdb6ce; long S198a6617dc07f3411d5c2ab23837bf26; unsigned long 
Sdebc544362bc88fbc79869c3454e638e; bool *Sf08fc651063a116b713c21fe0483d8e6; bool *S97237417ba96257dcca522646834e728; 
bool *Sf4fc158ddab359ab818e5fe86c1d181a; bool Sfedb2d84cafe20862cb4399751a8a7e3; S749d2b576e15d77f0d14f186077e9ace 
S9c28d32df234037773be184dbdafc274; S749d2b576e15d77f0d14f186077e9ace S2f0056df010e0231e4cca0e382df44fc; 
S749d2b576e15d77f0d14f186077e9ace S19348e0dd916770fabf9aa0f52d4096f; S749d2b576e15d77f0d14f186077e9ace 
S313849eaa8faa860e8d5639857e4b45b; public: bool Se4d23e841d8e8804190027bce3180fa5; S61b72eb6355a70814ce18eb4f7efa68a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, unsigned long Sa1e1f9c9bdfe7685923fdcc864bb786d, unsigned long S334186d69ff0c3752a510764ff3936fb); 
S61b72eb6355a70814ce18eb4f7efa68a(Se812b5a98988bad1d5b8df118cb6cc7f &S8c9a70dc1e604715e475d87430ba602d, 
unsigned long Sa1e1f9c9bdfe7685923fdcc864bb786d, const char *S7b0bb31f74b768daebbb6fb1a58041d9); S61b72eb6355a70814ce18eb4f7efa68a(const 
S61b72eb6355a70814ce18eb4f7efa68a &S86f8ed871a2e326f1154816761110c14); S61b72eb6355a70814ce18eb4f7efa68a(const 
S61b72eb6355a70814ce18eb4f7efa68a *S86f8ed871a2e326f1154816761110c14); ~S61b72eb6355a70814ce18eb4f7efa68a(void); 
S749d2b576e15d77f0d14f186077e9ace S77c92c7ddc071b07c527c9aa316f9328(void); S749d2b576e15d77f0d14f186077e9ace 
S3847bcc45274dd7c7e58efde3c5bef5a(void); S749d2b576e15d77f0d14f186077e9ace S73adfbe2da28341c45025580f412dc2a(void); 
S749d2b576e15d77f0d14f186077e9ace S2039596f6ccbcda87d5cea9313eb875c(void); bool S86630e1219027176737806157efbaf85(bool 
S573dda16c70458ee6b07a928cb142ddd) const; unsigned long Se4b88616283e7b4ddbb47516cb65dd36(void); void 
Sb124f23641d6f0fbf485d960ab72f437(unsigned long Sd95f9e04ad300554e3b6d2a4adfce1d2); unsigned long S993245c02a3c79568cb78880cd19a354(void); 
bool S02c10b49404aaec2099505999fe25cc5(void); bool Sf5153c63562142755896713a10b182d8(S61b72eb6355a70814ce18eb4f7efa68a 
&S059e8e571ae4fde1edb06763ac8d24f3); unsigned long S6e8c99bdce2bf9e14b6551fe3fd8cfe4(void); unsigned 
long S0cc61c6ca9d6e8d9782916904cc7f3c3(void); unsigned long Sde05f11e7794a28277eebf072900317c(void); 
unsigned long S0a0d318df5c053ae7319b1ec49b6e5e8(unsigned long Sc9e9a848920877e76685b2e4e76de38d = 0); 
unsigned long S2c8387b06995b10ae9a20fd58f79f49b(unsigned long Sc9e9a848920877e76685b2e4e76de38d = 0); 
unsigned long Sa90ec4ae976bb784cdc7b0bb80b48e1e(void);  bool *Se9ef9363cbe9a5f39a8cb510a2e042f0(void); 
void S97f1e170874a22f3776249625ec3d7b8( void *S0c9e7da67cf114aa81ef570bf9b35e6b); bool operator ==(const 
S61b72eb6355a70814ce18eb4f7efa68a &S86f8ed871a2e326f1154816761110c14); bool operator !=(const S61b72eb6355a70814ce18eb4f7efa68a 
&S86f8ed871a2e326f1154816761110c14); void S13dba24862cf9128167a59100e154c8d(S1356d0666866080ee569a8007f7465e0 
&Sd95679752134a2d9eb61dbd7b91c4bcc) const; };  typedef S61b72eb6355a70814ce18eb4f7efa68a *Sd8841b74cc206cdcb1580e1d6a9f3071; 
S1356d0666866080ee569a8007f7465e0 &operator << (S1356d0666866080ee569a8007f7465e0 &Sd95679752134a2d9eb61dbd7b91c4bcc, 
const S61b72eb6355a70814ce18eb4f7efa68a &S86f8ed871a2e326f1154816761110c14);
